@@ -132,7 +132,8 @@ auc = FALSE,
 max.iter = 100,
 near.zero.var = FALSE,
 progressBar = TRUE,
-class.object = NULL
+class.object = NULL,
+cl
 )
 {    #-- checking general input parameters --------------------------------------#
     #---------------------------------------------------------------------------#
@@ -145,8 +146,10 @@ class.object = NULL
         pb = FALSE
     }
     
+
+    
     M = length(folds)
-    features = NULL
+    features = features.j = NULL
     auc.all = prediction.comp = class.comp = list()
     for(ijk in dist)
     class.comp[[ijk]] = array(0, c(nrow(X), nrepeat, length(test.keepX)))# prediction of all samples for each test.keepX and  nrep at comp fixed
@@ -171,7 +174,7 @@ class.object = NULL
             repeated.measure = multilevel[,1]
             n = length(unique(repeated.measure)) # unique observation: we put every observation of the same "sample" in the either the training or test set
         }
-       
+        
         
         #-- define the folds --#
         if (validation ==  "Mfold")
@@ -210,7 +213,9 @@ class.object = NULL
         # in case the test set only includes one sample, it is better to advise the user to
         # perform loocv
         stop.user = FALSE
-        for (j in 1:M)
+
+        # function instead of a loop so we can use lapply and parLapply. Can't manage to put it outside without adding all the arguments
+        fonction.j.folds = function(j)#for (j in 1:M)
         {
             if (progressBar ==  TRUE)
             setTxtProgressBar(pb, (M*(nrep-1)+j-1)/(M*nrepeat))
@@ -218,13 +223,13 @@ class.object = NULL
             #print(j)
             #set up leave out samples.
             omit = which(repeated.measure %in% folds[[j]] == TRUE)
-
+            
             # get training and test set
             X.train = X[-omit, ]
             Y.train = Y[-omit]
             X.test = X[omit, , drop = FALSE]#matrix(X[omit, ], nrow = length(omit)) #removed to keep the colnames in X.test
             Y.test = Y[omit]
-   
+            
             #---------------------------------------#
             #-- near.zero.var ----------------------#
             
@@ -235,22 +240,98 @@ class.object = NULL
             {
                 X.train = X.train[, -c(ind.var),drop = FALSE]
                 X.test = X.test[, -c(ind.var),drop = FALSE]
+                
+                # match choice.keepX, choice.keepX.constraint and test.keepX if needed
+                if(is.null(choice.keepX.constraint) & !is.list(test.keepX))
+                {
+                    # keepX = c(choice.keepX, test.keepX[i])
+                    # keepX.constraint = NULL
+                    
+                    # reduce choice.keepX and test.keepX if needed
+                    if (any(choice.keepX > ncol(X.train)))
+                    choice.keepX[which(choice.keepX>ncol(X.train))] = ncol(X.train)
+                    
+                    if (any(test.keepX > ncol(X.train)))
+                    test.keepX[which(test.keepX>ncol(X.train))] = ncol(X.train)
+                    
+                } else if(!is.list(test.keepX)){
+                    # keepX = test.keepX[i]
+                    # keepX.constraint = choice.keepX.constraint
+                    
+                    # reduce test.keepX if needed
+                    if (any(test.keepX > ncol(X.train)))
+                    test.keepX[which(test.keepX>ncol(X.train))] = ncol(X.train)
+                    
+                    choice.keepX.constraint = match.keepX.constraint(names.remove = names(ind.var), keepX.constraint = choice.keepX.constraint)
+                    
+                } else {
+                    # keepX = NULL
+                    # keepX.constraint = c(choice.keepX.constraint, test.keepX)
+                    
+                    # reduce choice.keepX.constraint if needed
+                    choice.keepX.constraint = match.keepX.constraint(names.remove = names(ind.var), keepX.constraint = c(choice.keepX.constraint, test.keepX))
+                    
+                }
+                
             }
             
-            
             if(near.zero.var == TRUE)
             {
                 remove.zero = nearZeroVar(X.train)$Position
                 
                 if (length(remove.zero) > 0)
                 {
+                    names.var = colnames(X.train)[remove.zero]
+                    
                     X.train = X.train[, -c(remove.zero),drop = FALSE]
                     X.test = X.test[, -c(remove.zero),drop = FALSE]
+                    
+                    # match choice.keepX, choice.keepX.constraint and test.keepX if needed
+                    if(is.null(choice.keepX.constraint) & !is.list(test.keepX))
+                    {
+                        # keepX = c(choice.keepX, test.keepX[i])
+                        # keepX.constraint = NULL
+                        
+                        # reduce choice.keepX and test.keepX if needed
+                        if (any(choice.keepX > ncol(X.train)))
+                        choice.keepX[which(choice.keepX>ncol(X.train))] = ncol(X.train)
+                        
+                        if (any(test.keepX > ncol(X.train)))
+                        test.keepX[which(test.keepX>ncol(X.train))] = ncol(X.train)
+                        
+                    } else if(!is.list(test.keepX)){
+                        # keepX = test.keepX[i]
+                        # keepX.constraint = choice.keepX.constraint
+                        
+                        # reduce test.keepX if needed
+                        if (any(test.keepX > ncol(X.train)))
+                        test.keepX[which(test.keepX>ncol(X.train))] = ncol(X.train)
+                        
+                        choice.keepX.constraint = match.keepX.constraint(names.remove = names.var, keepX.constraint = choice.keepX.constraint)
+                        
+                    } else {
+                        # keepX = NULL
+                        # keepX.constraint = c(choice.keepX.constraint, test.keepX)
+                        
+                        # reduce choice.keepX.constraint if needed
+                        choice.keepX.constraint = match.keepX.constraint(names.remove = names.var, keepX.constraint = c(choice.keepX.constraint, test.keepX))
+                        
+                    }
+                    
                 }
+                #print(remove.zero)
             }
             
             #-- near.zero.var ----------------------#
             #---------------------------------------#
+            prediction.comp.j = array(0, c(length(omit), nlevels(Y), length(test.keepX)), dimnames = list(rownames(X.test), levels(Y), names(test.keepX)))
+            
+            
+            class.comp.j = list()
+            for(ijk in dist)
+            class.comp.j[[ijk]] = matrix(0, nrow = length(omit), ncol = length(test.keepX))# prediction of all samples for each test.keepX and  nrep at comp fixed
+            
+            
             for (i in 1:length(test.keepX))
             {
                 if (progressBar ==  TRUE)
@@ -264,21 +345,53 @@ class.object = NULL
                 keepX = if(is.null(choice.keepX.constraint) & !is.list(test.keepX)){c(choice.keepX, test.keepX[i])}else if(!is.list(test.keepX)){test.keepX[i]} else {NULL} ,
                 keepX.constraint = if(is.null(choice.keepX.constraint)& !is.list(test.keepX)){NULL}else if(!is.list(test.keepX)){choice.keepX.constraint} else {c(choice.keepX.constraint, test.keepX)},
                 logratio = "none", near.zero.var = FALSE, mode = "regression", max.iter = max.iter)
-                  
+                
                 # added: record selected features
                 if (any(class.object %in% c("splsda")) & length(test.keepX) ==  1) # only done if splsda and if only one test.keepX as not used if more so far
                 # note: if plsda, 'features' includes everything: to optimise computational time, we don't evaluate for plsda object
-                features = c(features, selectVar(object.res, comp = ncomp)$name)
+                features.j = selectVar(object.res, comp = ncomp)$name
                 
                 test.predict.sw <- predict(object.res, newdata = X.test, method = dist)
-                prediction.comp[[nrep]][omit, , i] =  test.predict.sw$predict[, , ncomp]
+                prediction.comp.j[, , i] =  test.predict.sw$predict[, , ncomp]
                 
                 for(ijk in dist)
-                class.comp[[ijk]][omit,nrep,i] =  test.predict.sw$class[[ijk]][, ncomp] #levels(Y)[test.predict.sw$class[[ijk]][, ncomp]]
+                class.comp.j[[ijk]][, i] =  test.predict.sw$class[[ijk]][, ncomp] #levels(Y)[test.predict.sw$class[[ijk]][, ncomp]]
             } # end i
             
-        } # end j 1:M (M folds)
+            
+            return(list(class.comp.j = class.comp.j, prediction.comp.j = prediction.comp.j, features = features.j, omit = omit))
+            
+        } # end fonction.j.folds
+
+
+
+        if (!is.null(cl) == TRUE)
+        {
+            result = parLapply(cl, 1: M, fonction.j.folds)
+        } else {
+            result = lapply(1: M, fonction.j.folds)
+            
+        }
+
+        # combine the results
+        for(j in 1:M)
+        {
+            omit = result[[j]]$omit
+            prediction.comp.j = result[[j]]$prediction.comp.j
+            class.comp.j = result[[j]]$class.comp.j
+
+            prediction.comp[[nrep]][omit, , ] = prediction.comp.j
+            
+            for(ijk in dist)
+            class.comp[[ijk]][omit,nrep, ] = class.comp.j[[ijk]]
+            
+            if (any(class.object %in% c("splsda")) & length(test.keepX) ==  1) # only done if splsda and if only one test.keepX as not used if more so far
+            features = c(features, result[[j]]$features)
+
+        }
         
+
+
         if (progressBar ==  TRUE)
         setTxtProgressBar(pb, (M*nrep)/(M*nrepeat))
         
@@ -292,12 +405,12 @@ class.object = NULL
                 auc.all[[nrep]][, , i] = as.matrix(statauc(data))
             }
         }
-
+        
     } #end nrep 1:nrepeat
+    
     names(prediction.comp) = names (auc.all) = paste0("nrep.", 1:nrepeat)
     # class.comp[[ijk]] is a matrix containing all prediction for test.keepX, all nrepeat and all distance, at comp fixed
     
-    save(list=ls(),file="temp.Rdata")
     # average auc over the nrepeat, for each test.keepX
     if(auc)
     {
@@ -444,6 +557,3 @@ class.object = NULL
     result$features$stable = sort(table(as.factor(features))/M/nrepeat, decreasing = TRUE)
     return(result)
 }
-
-
-
