@@ -66,6 +66,9 @@ near.zero.var = FALSE)
     result = internal_wrapper.mint.block(X=X, Y=Y, indY=indY, ncomp=ncomp, design=design, scheme=scheme, mode=mode, scale=scale,
     bias=bias, init=init, tol=tol, verbose=verbose ,max.iter=max.iter ,near.zero.var=near.zero.var)
     
+    # calculate weights for each dataset
+    weights = get.weights(result$variates, indY = result$indY)
+
     # choose the desired output from 'result'
     out=list(call = match.call(),
         X = result$X,
@@ -74,6 +77,7 @@ near.zero.var = FALSE)
         mode = result$mode,
         variates = result$variates,
         loadings = result$loadings,
+        crit = result$crit,
         names = result$names,
         init = result$init,
         bias = result$bias,
@@ -84,6 +88,7 @@ near.zero.var = FALSE)
         scale = result$scale,
         design = result$design,
         scheme = result$scheme,
+        weights = weights,
         explained_variance = result$explained_variance)
     
     # give a class
