@@ -102,6 +102,9 @@ near.zero.var = FALSE)
     result = internal_wrapper.mint.block(X=X, Y=Y, indY=indY, ncomp=ncomp, design=design, scheme=scheme, mode=mode, scale=scale,
     bias=bias, init=init, tol=tol, verbose=verbose, max.iter=max.iter, near.zero.var=near.zero.var)
 
+    # calculate weights for each dataset
+    weights = get.weights(result$variates, indY = result$indY)
+
     # choose the desired output from 'result'
     out=list(call = match.call(),
         X = result$X[-result$indY],
@@ -111,6 +114,7 @@ near.zero.var = FALSE)
         mode = result$mode,
         variates = result$variates,
         loadings = result$loadings,
+        crit = result$crit,
         names = result$names,
         init = result$init,
         bias = result$bias,
@@ -122,7 +126,8 @@ near.zero.var = FALSE)
         design = result$design,
         scheme = result$scheme,
         indY = result$indY,
-        explained_variance = result$explained_variance[-result$indY])
+        weights = weights,
+        explained_variance = result$explained_variance)#[-result$indY])
     
     # give a class
     class(out) = c("block.plsda","block.pls","sgccda","sgcca","DA")
