@@ -90,7 +90,7 @@ layout = NULL,
     nResp = nrow(y)  # Number of response variables
     nComp = ncol(y)  # Number of components
     
-    def.par = par(no.readonly = TRUE)
+    #def.par = par(no.readonly = TRUE)
 
     if (nResp > 1) {
         if (is.null(layout)) {
@@ -107,8 +107,7 @@ layout = NULL,
         
         if (nRows * nCols < nResp) devAskNewPage(TRUE)
         ynames = rownames(y)
-    }
-    else {
+    } else {
         ynames = "Y"
     }
     
@@ -145,14 +144,19 @@ layout = NULL,
                 if (LimQ2.col != "none") panel.abline(h = LimQ2, col = LimQ2.col)
                 panel.xyplot(x, y, ...)})
         }
-    }
-    else {
-        xyplot(val ~ comps | varName, data = df, xlab = xlab, ylab = ylab,
+    } else {
+        plt = xyplot(val ~ comps | varName, data = df, xlab = xlab, ylab = ylab,
         scales = list(y = yList, x = list(at = cTicks)),
         as.table = TRUE, layout = layout, ...)
+        plot(plt)
+
     }
     
-    par(def.par)
+    if (nResp > 1) {
+        if (nRows * nCols < nResp) devAskNewPage(FALSE)
+    }
+
+    #par(def.par)
     
     
 }
@@ -164,6 +168,7 @@ plot.perf.plsda.mthd = plot.perf.splsda.mthd =
 function (x,
 dist = c("all","max.dist","centroids.dist","mahalanobis.dist"),
 measure = c("all","overall","BER"),
+col,
 xlab = NULL,
 ylab = NULL,
 overlay=c("all", "measure", "dist"),
@@ -192,6 +197,14 @@ sd = TRUE,
     if (is.null(dist) || !any(dist %in% colnames(x$error.rate[[1]])))
     stop("'dist' should be among the ones used in your call to 'perf': ", paste(colnames(x$error.rate[[1]]),collapse = ", "),".")
     
+    if(missing(col)) #one col per distance
+    {
+        col = color.mixo(1:length(dist))
+    } else {
+        if(length(col) != length(dist))
+        stop("'col' should be a vector of length ", length(dist),".")
+    }
+    
     if (is.null(ylab))
     ylab = 'Classification error rate'
     
@@ -218,7 +231,7 @@ sd = TRUE,
     
     internal_graphic.perf(error.rate = error.rate, error.rate.sd = error.rate.sd,
     overlay = overlay, type = type, measure = measure, dist = dist, legend.position = legend.position,
-    xlab = xlab, ylab = ylab, sd = sd,  ...)
+    xlab = xlab, ylab = ylab, sd = sd, color = col, ...)
     
     par(def.par)
     # error.bar(out,as.vector(mat.error.plsda),as.vector(cbind(x$error.rate.sd$overall,x$error.rate.sd$BER)))
@@ -234,6 +247,7 @@ plot.perf.mint.plsda.mthd = plot.perf.mint.splsda.mthd =
 function (x,
 dist = c("all","max.dist","centroids.dist","mahalanobis.dist"),
 measure = c("all","overall","BER"),
+col,
 xlab = NULL,
 ylab = NULL,
 study = "global",
@@ -265,6 +279,14 @@ legend.position=c("vertical", "horizontal"),
     if(length(legend.position) >1 )
     legend.position = legend.position[1]
 
+    if(missing(col)) #one col per distance
+    {
+        col = color.mixo(1:length(dist))
+    } else {
+        if(length(col) != length(dist))
+        stop("'col' should be a vector of length ", length(dist),".")
+    }
+
 
     if(any(study == "global"))
     {
@@ -288,7 +310,7 @@ legend.position=c("vertical", "horizontal"),
         
         internal_graphic.perf(error.rate = error.rate, error.rate.sd = NULL,
         overlay = overlay, type = type, measure = measure, dist = dist, legend.position = legend.position,
-        xlab = xlab, ylab = ylab, ...)
+        xlab = xlab, ylab = ylab, color = col, ...)
         
         par(def.par)
         
@@ -335,7 +357,7 @@ legend.position=c("vertical", "horizontal"),
 
             internal_graphic.perf(error.rate = error.rate, error.rate.sd = NULL,
             overlay = overlay, type = type, measure = measure, dist = dist, legend.position = legend.position,
-            xlab = xlab, ylab = ylab, ...)
+            xlab = xlab, ylab = ylab, color = col, ...)
             
             if (overlay == "all")
             title(stu, line = 1)
@@ -359,6 +381,8 @@ plot.perf.sgccda.mthd =
 function (x,
 dist = c("all","max.dist","centroids.dist","mahalanobis.dist"),
 measure = c("all","overall","BER"),
+col,
+weighted = TRUE,
 xlab = NULL,
 ylab = NULL,
 overlay= c("all", "measure", "dist"),
@@ -400,12 +424,27 @@ legend.position=c("vertical","horizontal"),
     if (is.null(dist) || !any(dist %in% colnames(x$error.rate[[1]])))
     stop("'dist' should be among the ones used in your call to 'perf': ", paste(colnames(x$error.rate[[1]]),collapse = ", "),".")
     
+    if(missing(col)) #one col per distance
+    {
+        col = color.mixo(1:length(dist))
+    } else {
+        if(length(col) != length(dist))
+        stop("'col' should be a vector of length ", length(dist),".")
+    }
+    
     if (is.null(ylab))
     ylab = 'Classification error rate'
    
     if (is.null(xlab))
     xlab = 'Component'
-        
+    
+    if(weighted == TRUE)
+    {
+        perfo = "WeightedVote.error.rate"
+    } else {
+        perfo = "MajorityVote.error.rate"
+    }
+    
     # error.rate is a list [[measure]]
     # error.rate[[measure]] is a matrix of dist columns and ncomp rows
     # same for error.rate.sd, if any
@@ -415,7 +454,7 @@ legend.position=c("vertical","horizontal"),
         error.temp = NULL
         for(di in dist)
         {
-            temp = t(x$MajorityClass.error.rate[[di]][mea, , drop=FALSE])
+            temp = t(x[[perfo]][[di]][mea, , drop=FALSE])
             colnames(temp) = di
             error.temp = cbind(error.temp, temp)
 
@@ -429,7 +468,7 @@ legend.position=c("vertical","horizontal"),
     
     internal_graphic.perf(error.rate = error.rate, error.rate.sd = NULL,
     overlay = overlay, type = type, measure = measure, dist = dist, legend.position = legend.position,
-    xlab = xlab, ylab = ylab, ...)
+    xlab = xlab, ylab = ylab, color = col, ...)
     
     par(def.par)
     return(invisible())
