@@ -39,7 +39,7 @@
 
 predict.block.pls <-predict.block.spls <- predict.mint.splsda <-
 predict.pls <-predict.spls <-
-function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist", "mahalanobis.dist"), multilevel = NULL,  ...)
+function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist", "mahalanobis.dist"), multilevel = NULL, ...)
 {
     
     if(any(class(object)%in%c("rgcca","sparse.rgcca")))
@@ -131,7 +131,7 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
         object$X=X
 
         p = lapply(X, ncol)
-        
+
         #matching newdata and X
         
         # error if no names on keepX or not matching the names in X
@@ -211,7 +211,7 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
     
     # logratio and multilevel transform if necessary
     if (!is.null(object$logratio))
-    newdata2 = lapply(newdata, logratio.transfo, logratio = object$logratio)
+    newdata = lapply(newdata, logratio.transfo, logratio = object$logratio)
     
     if(!is.null(multilevel))
     newdata = lapply(newdata, withinVariation, design = data.frame(multilevel))
@@ -423,20 +423,75 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
     
 
     # basic prediction results
-    if(length(grep("block",class(object)))!=0 )
+    if(length(grep("block",class(object)))!=0 & length(object$X)>1 )
     {
         out=list(predict=Y.hat[which(!is.na(ind.match))],variates=t.pred[which(!is.na(ind.match))],B.hat=B.hat[which(!is.na(ind.match))])
-        #out$newdata=concat.newdata
-    }else{# not a block (pls/spls/plsda/splsda/mint...)
-        out=list(predict=Y.hat[[1]],variates=t.pred[[1]],B.hat=B.hat[[1]])
-        #out$newdata=concat.newdata[[1]]
         
-    }
+        # average prediction over the blocks
+        temp.all =list()
+        for(comp in 1:min(ncomp[-object$indY])) #note: all ncomp are the same in v6 as the input parameter is a single value
+        {
+            temp = array(0, c(nrow(Y.hat[[1]]), ncol(Y.hat[[1]]), J), dimnames = list(rownames(newdata[[1]]), colnames(Y),names(object$X)))
+            for(i in 1 : J)
+            temp[, , i] = Y.hat[[i]][, , comp]
+            
+            temp.all[[comp]] = temp
+        }
+        names(temp.all) = paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")
+        
+        out$AveragedPredict = array(unlist(lapply(temp.all, function(x){apply(x, c(1,2), mean)})), dim(Y.hat[[1]]), dimnames = list(rownames(newdata[[1]]), colnames(Y), paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")))
+        
+        out$WeightedPredict = array(unlist(lapply(temp.all, function(x){apply(x, c(1,2), function(z){
+            temp = aggregate(object$weights,list(z),sum)
+            ind = which(temp[,2]== max (temp[,2]))# if two max, then NA
+            if(length(ind) == 1)
+            {
+                res = temp[ind, 1]
+            } else {
+                res = NA
+            }
+            res
+        })})), dim(Y.hat[[1]]), dimnames = list(rownames(newdata[[1]]), colnames(Y), paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")))
 
 
+        #out$newdata=concat.newdata
+    }else if(length(grep("block",class(object)))!=0){ # a block but can have only one block (so e.g. a pls done with a block.pls)
+        out=list(predict=Y.hat,variates=t.pred,B.hat=B.hat)
+        
+    } else {# not a block (pls/spls/plsda/splsda/mint...)
+        out=list(predict=Y.hat[[1]],variates=t.pred[[1]],B.hat=B.hat[[1]])
+    }
+
     # get the classification for each new sample if the object is a DA
     if(any(class(object)=="DA")) # a DA analysis (mint).(block).(s)plsda
     {
+        
+        if(length(grep("block",class(object)))!=0 & length(object$X)>1 )
+        {
+
+            # predict class of AveragePredict, only with max.dist
+            out$AveragedPredict.class$max.dist = matrix(sapply(1:ncomp[1], ### List level
+                function(y){apply(out$AveragedPredict[, , y, drop = FALSE], 1,  ### component level
+                    function(z){
+                        paste(levels(Y.factor)[which(z == max(z))], collapse = "/")
+                    }) ### matrix level
+                }), nrow = nrow(newdata[[1]]), ncol = ncomp[1])
+            
+            
+            # predict class of WeightedPredict, only with max.dist
+            out$WeightedPredict.class$max.dist = matrix(sapply(1:ncomp[1], ### List level
+            function(y){apply(out$WeightedPredict[, , y, drop = FALSE], 1,  ### component level
+                function(z){
+                    paste(levels(Y.factor)[which(z == max(z))], collapse = "/")
+                }) ### matrix level
+            }), nrow = nrow(newdata[[1]]), ncol = ncomp[1])
+            
+            rownames(out$AveragedPredict.class$max.dist) = rownames(out$WeightedPredict.class$max.dist) = rownames(newdata[[1]])
+            colnames(out$AveragedPredict.class$max.dist) = colnames(out$WeightedPredict.class$max.dist) = paste("dim", c(1:min(ncomp[-object$indY])), sep = " ")
+        }
+        
+        
+        
         # creating temporary 'blocks' outputs to pass into the internal_predict.DA function
         out.temp=list(predict=Y.hat[which(!is.na(ind.match))],variates=t.pred[which(!is.na(ind.match))],B.hat=B.hat[which(!is.na(ind.match))])
         out.temp$newdata=concat.newdata[which(!is.na(ind.match))]
@@ -445,7 +500,7 @@ function(object, newdata,study.test,dist = c("all", "max.dist", "centroids.dist"
         object.temp = object
         object.temp$X = object.temp$X[which(!is.na(ind.match))]
         object.temp$variates = object.temp$variates[c(which(!is.na(ind.match)),J+1)] #J+1 is Y
-        classif.DA=internal_predict.DA(object=object.temp,q=q,out=out.temp,dist=dist)
+        classif.DA=internal_predict.DA(object=object.temp, q=q, out=out.temp, dist=dist, weights = object$weights[which(!is.na(ind.match))])
         out=c(out,classif.DA)
         
     }
