@@ -58,6 +58,7 @@ validation = "Mfold",
 folds = 10,
 dist = "max.dist",
 measure = "BER", # one of c("overall","BER")
+weighted = TRUE, # optimise the weighted or not-weighted prediction
 progressBar = TRUE,
 max.iter = 100,
 near.zero.var = FALSE,
@@ -70,8 +71,9 @@ bias,
 init ,
 tol = 1e-06,
 verbose,
-light.output = TRUE # if FALSE, output the prediction and classification of each sample during each folds, on each comp, for each repeat
-)
+light.output = TRUE, # if FALSE, output the prediction and classification of each sample during each folds, on each comp, for each repeat
+cpus,
+name.save = NULL)
 {
     #-- checking general input parameters --------------------------------------#
     #---------------------------------------------------------------------------#
@@ -111,8 +113,10 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
         stop("Either 'Y' or 'indY' is needed")
         
     }
-
     
+    #-- dist
+    dist = match.arg(dist, choices = c("max.dist", "centroids.dist", "mahalanobis.dist"), several.ok = FALSE)
+
     #-- progressBar
     if (!is.logical(progressBar))
     stop("'progressBar' must be a logical constant (TRUE or FALSE).", call. = FALSE)
@@ -131,7 +135,7 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
     if (validation == 'loo')
     {
         if (nrepeat != 1)
-        warnings("Leave-One-Out validation does not need to be repeated: 'nrepeat' is set to '1'.")
+        warning("Leave-One-Out validation does not need to be repeated: 'nrepeat' is set to '1'.")
         nrepeat = 1
     }
     
@@ -146,8 +150,8 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
     } else {
         stop("'measure' must be 'overall' or 'BER'")
     }
-
-
+    
+    
     #-- already.tested.X
     if (missing(already.tested.X))
     {
@@ -167,8 +171,8 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
         # we require the same number of already tuned components on each block
         if(length(unique(sapply(already.tested.X, length))) > 1)
         stop("The same number of components must be already tuned for each block, in 'already.tested.X'")
-
-
+        
+        
         if(constraint == TRUE)
         {
             if(any(sapply(already.tested.X, function(x) is.list(x))) != TRUE)
@@ -201,7 +205,7 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
         aa = sapply(test.keepX, length)
         if (any(is.null(aa) | aa == 1 | !is.numeric(aa)))
         stop("Each entry of 'test.keepX' must be a numeric vector with more than two values", call. = FALSE)
-
+        
     }
     
     l = sapply(test.keepX,length)
@@ -209,16 +213,33 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
     temp = data.frame(l, n)
     
     
-    message(paste("You have provided a sequence of keepX of length: ", paste(apply(temp, 1, function(x) paste(x,collapse=" for block ")), collapse= " and "), ".\nThis results in ",prod(sapply(test.keepX,length)), " models being fitted for each component, this may take some time to run, be patient!",sep=""))
+    message(paste("You have provided a sequence of keepX of length: ", paste(apply(temp, 1, function(x) paste(x,collapse=" for block ")), collapse= " and "), ".\nThis results in ",prod(sapply(test.keepX,length)), " models being fitted for each component and each nrepeat, this may take some time to run, be patient!",sep=""))
     
+    if(missing(cpus))
+    {
+        parallel = FALSE
+        message(paste("You can look into the 'cpus' argument to speed up computation time.",sep=""))
+
+    } else {
+        parallel = TRUE
+        if(progressBar == TRUE)
+        message(paste("As code is running in parallel, the progressBar will only show 100% upon completion of each component.",sep=""))
+
+    }
     
+    if(weighted == TRUE)
+    {
+        perfo = paste0("WeightedVote.error.rate.",dist)
+    } else {
+        perfo = paste0("MajorityVote.error.rate.",dist)
+    }
     #-- end checking --#
     #------------------#
     
     test.keepX = lapply(test.keepX,sort) #sort test.keepX so as to be sure to chose the smallest in case of several minimum
-
+    
     grid = expand.grid (test.keepX[length(test.keepX):1])[length(test.keepX):1] # each row is to be tested, the reordering is just a personal preference, works without it
-
+    
     # if some components have already been tuned (eg comp1 and comp2), we're only tuning the following ones (comp3 comp4 .. ncomp)
     if ((!is.null(already.tested.X)) & length(already.tested.X) > 0)
     {
@@ -236,14 +257,62 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
         {
             if(length(unique(names(already.tested.X)))!=length(already.tested.X) | sum(is.na(match(names(already.tested.X),names(X)))) > 0)
             stop("Each entry of 'already.tested.X' must have a unique name corresponding to a block of 'X'")
-
+            
         }
         
     } else {
         comp.real = 1:ncomp
     }
+    
+    
+    if (parallel == TRUE)
+    cl <- makeCluster(cpus, type = "SOCK")
+    
+    
+    fonction.indice.grid = function(indice.grid, mode, design, scheme, bias, init, verbose){
+        test.keepX.comp = grid[indice.grid,]
+        
+        if(constraint == FALSE)
+        {
+            keepX.temp = lapply(1:length(X), function(x){c(already.tested.X[[x]],test.keepX.comp[[x]])})
+            names(keepX.temp) = names(X)
+        }
+        
+        # run block.splsda
+        model = suppressMessages(block.splsda(X = X, Y = Y, ncomp=comp.real[comp],
+        keepX.constraint = if(constraint){already.tested.X}else{NULL},
+        keepX = if(constraint){test.keepX.comp}else{keepX.temp},
+        design=design, scheme=scheme, mode=mode, scale=scale,
+        bias=bias, init=init, tol=tol, verbose=verbose, max.iter=max.iter, near.zero.var=near.zero.var))
+        
+        
+        # run perf on the model
+        cvPerf = lapply(1 : nrepeat, function(u){out = suppressMessages(perf(model, validation = validation, folds = folds, dist = dist));
+            if (progressBar ==  TRUE)
+            setTxtProgressBar(pb, ((indice.grid-1)*nrepeat+u)/(nrow(grid)*nrepeat))
+            out
+        })
+        names(cvPerf) = paste("nrepeat",1:nrepeat,sep="")
+        
+        # record results
+        ## Majority Vote
+        if(weighted == TRUE)
+        {
+            cvPerf2 = lapply(1 : nrepeat, function(x){unlist(cvPerf[[x]][names(cvPerf[[x]]) == "WeightedVote.error.rate"], recursive = FALSE)})
+            names(cvPerf2) = paste("nrepeat",1:nrepeat,sep="")
+        } else {
+            cvPerf2 = lapply(1 : nrepeat, function(x){unlist(cvPerf[[x]][names(cvPerf[[x]]) == "MajorityVote.error.rate"], recursive = FALSE)})
+            names(cvPerf2) = paste("nrepeat",1:nrepeat,sep="")
+        }
 
 
+    
+        setTxtProgressBar(pb, indice.grid/nrow(grid))
+        
+        return(cvPerf2)
+    }
+    
+    
     keepX = error.rate = mat.sd.error = NULL
     mat.error.rate = list()
     error.per.class.keepX.opt=list()
@@ -263,57 +332,55 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
         result.comp = matrix(nrow=nrow(grid),ncol=1)
         error.mean = error.sd = mat.error.rate.keepX = NULL
         error.per.class = array(0,c(nlevels(Y),nrepeat,nrow(grid)),dimnames = list(levels(Y), paste("nrep",1:nrepeat,sep=".")))
+        
+
+        if (parallel == TRUE)
+        {
+            clusterExport(cl, c("block.splsda","perf"))
+            cvPerf3 = parLapply(cl, 1: nrow(grid), fonction.indice.grid)
+        } else {
+            cvPerf3 = lapply(1: nrow(grid), fonction.indice.grid)
+            
+        }
+        names(cvPerf3) = paste("indice.grid",1:nrow(grid),sep="")
+        
+
+        
+        
         for(indice.grid in 1 : nrow(grid))
         {
             # test.keepX.comp: keepX for each block on component "comp.real[comp]"
             # already.tested.X: either keepX (constraint=FALSE) or keepX.constraint.temp (constraint=TRUE) for all block on components 1:(comp.real[comp]-1)
             # keepX.temp: keepX for all block on all component 1:comp.real[comp], only used if constraint=FALSE
-            
-            test.keepX.comp = grid[indice.grid,]
-            
-            if(constraint == FALSE)
-            {
-                keepX.temp = lapply(1:length(X), function(x){c(already.tested.X[[x]],test.keepX.comp[[x]])})
-                names(keepX.temp) = names(X)
-            }
-            
-            # run block.splsda
-            model = suppressMessages(block.splsda(X = X, Y = Y, ncomp=comp.real[comp],
-            keepX.constraint = if(constraint){already.tested.X}else{NULL},
-            keepX = if(constraint){test.keepX.comp}else{keepX.temp},
-            design=design, scheme=scheme, mode=mode, scale=scale,
-            bias=bias, init=init, tol=tol, verbose=verbose, max.iter=max.iter, near.zero.var=near.zero.var))
-            
-            
-            # run perf on the model
-            cvPerf = lapply(1 : nrepeat, function(u){out = suppressMessages(perf(model, validation = validation, folds = folds, dist = dist));
-                if (progressBar ==  TRUE)
-                setTxtProgressBar(pb, ((indice.grid-1)*nrepeat+u)/(nrow(grid)*nrepeat))
-                out
-            })
-
-            # record results
-            ## Majority Vote
-            cvPerf2 = lapply(1 : nrepeat, function(x){unlist(cvPerf[[x]][names(cvPerf[[x]]) == "MajorityClass.error.rate"], recursive = FALSE)})
-            mat.error.rate.temp = simplify2array( lapply(cvPerf2, function(x) x$"MajorityClass.error.rate"[measure,comp])) # error over the nrepeat
+            mat.error.rate.temp = simplify2array( lapply(cvPerf3[[indice.grid]], function(x) x[[perfo]][measure,comp])) # error over the nrepeat
             mat.error.rate.keepX = rbind(mat.error.rate.keepX, mat.error.rate.temp)
             
             error.mean = c(error.mean, mean(mat.error.rate.temp))
-            error.per.class[, , indice.grid] = simplify2array(lapply(cvPerf2, function(x){ x$"MajorityClass.error.rate"[1:nlevels(Y),comp]}))
+            error.per.class[, , indice.grid] = simplify2array(lapply(cvPerf3[[indice.grid]], function(x){ x[[perfo]][1:nlevels(Y),comp]}))
             
             if(nrepeat > 1)
-            error.sd = c(error.sd, apply(simplify2array(lapply(cvPerf2, function(x) x$"MajorityClass.error.rate")), c(1,2), sd)[measure,comp])
+            error.sd = c(error.sd, apply(simplify2array(lapply(cvPerf3[[indice.grid]], function(x) x[[perfo]])), c(1,2), sd)[measure,comp])
+            
+            #if (progressBar ==  TRUE)
+            #setTxtProgressBar(pb, (indice.grid)/nrow(grid))
             
-            if (progressBar ==  TRUE)
-            setTxtProgressBar(pb, (indice.grid)/nrow(grid))
         }
         
         names(error.mean) = apply(grid,1,function(x){paste(x, collapse = "_")})
         if(nrepeat > 1)
         names(error.sd) = names(error.mean)
         
-        min.keepX = names(which.min(error.mean))
-        a=as.numeric(strsplit(min.keepX,"_")[[1]]) # vector of each optimal keepX for all block on component comp.real[comp]
+        min.error = min(error.mean)
+        min.keepX = names(which(error.mean == min.error)) # vector of all keepX combination that gives the minimum error
+        
+        a = strsplit(min.keepX,"_") # list of all keepX combination
+        a = lapply(a, as.numeric) # transform characters of keepX into numbers
+        
+        #transform keepX in percentage of variable per dataset, so we choose the minimal overall
+        p = sapply(X,ncol)
+        percent = sapply(a, function(x) sum(x/p))
+        ind.opt = which.min(percent) # we take only one
+        a = a[[ind.opt]]# vector of each optimal keepX for all block on component comp.real[comp]
         
         # best keepX
         opt.keepX.comp = as.list(a)
@@ -328,7 +395,7 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
         {
             # add the optimal keepX to already.tested.X
             already.tested.X = lapply(1:length(X), function(x){c(already.tested.X[[x]],opt.keepX.comp[[x]])})
-
+            
         } else {
             # get the variables selected by the optimal keepX, and add them in already.tested.X
             fit = suppressMessages(block.splsda(X = X, Y = Y, ncomp=comp.real[comp],
@@ -344,16 +411,52 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
             {
                 already.tested.X = lapply(1:length(X), function(x){already.tested.X[[x]] = list()})
                 already.tested.X = lapply(1:length(X),function(x){already.tested.X[[x]][[comp.real[comp]]] = list("comp1" = selectVar(fit, comp = 1)[[x]]$"name")})
-
+                
             } else {
                 already.tested.X = lapply(1:length(X),function(x){already.tested.X[[x]] = c(already.tested.X[[x]], list(selectVar(fit, comp = comp.real[comp])[[x]]$"name")); names(already.tested.X[[x]]) = paste("comp",1:comp.real[comp],sep=""); return(already.tested.X[[x]])})
             }
         }
         names(already.tested.X) = names(X)
+        
+        
+        # prepping the results and save a file, if necessary
+        if(!is.null(name.save))
+        {
+            colnames(error.rate) = paste("comp", comp.real[1:comp], sep='')
+            names(mat.error.rate) = c(paste('comp', comp.real[1:comp], sep=''))
+            mat.error.rate = lapply(mat.error.rate, function(x) {colnames(x) = paste("nrep",1:nrepeat,sep="."); rownames(x) = rownames(error.rate);x})
+            names(error.per.class.keepX.opt) = c(paste('comp', comp.real[1:comp], sep=''))
+            
+            if(nrepeat > 1)
+            colnames(mat.sd.error) = paste("comp", comp.real[1:comp], sep='')
+            
+            
+            result = list(
+            error.rate = error.rate,
+            error.rate.sd = mat.sd.error,
+            error.rate.all = mat.error.rate,
+            choice.keepX = if(constraint){lapply(already.tested.X, function(x){sapply(x,length)})}else{already.tested.X},
+            choice.keepX.constraint = if(constraint){already.tested.X}else{NULL},
+            error.rate.class = error.per.class.keepX.opt)
+            
+            result$measure = measure.input
+            result$call = match.call()
+            
+            class(result) = "tune.block.splsda"
+        
+            save(result, file = paste0(name.save,".comp",comp.real[1],"to",comp.real[comp],".Rdata"))
+        }
+        
+        if (progressBar ==  TRUE)
+        setTxtProgressBar(pb, 1)
 
     }
+    #close the cluster after ncomp
+    if (parallel == TRUE)
+    stopCluster(cl)
+    
     cat("\n")
-   
+    
     colnames(error.rate) = paste("comp", comp.real, sep='')
     names(mat.error.rate) = c(paste('comp', comp.real, sep=''))
     mat.error.rate = lapply(mat.error.rate, function(x) {colnames(x) = paste("nrep",1:nrepeat,sep="."); rownames(x) = rownames(error.rate);x})
@@ -361,8 +464,8 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
     
     if(nrepeat > 1)
     colnames(mat.sd.error) = paste("comp", comp.real, sep='')
-
-
+    
+    
     result = list(
     error.rate = error.rate,
     error.rate.sd = mat.sd.error,
@@ -373,7 +476,7 @@ light.output = TRUE # if FALSE, output the prediction and classification of each
     
     result$measure = measure.input
     result$call = match.call()
-
+    
     class(result) = "tune.block.splsda"
     
     return(result)
