@@ -32,7 +32,7 @@ tau = rep(1, length(X)),
 ncomp = 1,
 keepX.constraint,
 keepX,
-scheme = "centroid",
+scheme = "horst",
 scale = TRUE,
 bias = FALSE,
 init = "svd.single",
