@@ -33,11 +33,11 @@ penalty = NULL,
 ncomp = 1,
 keepX.constraint,
 keepX,
-scheme = "centroid",
+scheme = "horst",
 mode = "canonical",
 scale = TRUE,
 bias = TRUE,
-init = "svd",
+init = "svd.single",
 tol = .Machine$double.eps,
 verbose = FALSE,
 max.iter = 1000,
